#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
    hipku
    ~~~~~

    Encode any IP address as a haiku.

    :copyright: (c) 2015 by lord63.
    :license: MIT, see LICENSE for more details.
"""

__title__ = "hipku"
__version__ = "0.1.0"
__author__ = "lord63"
__license__ = "MIT"
__copyright__ = "Copyright 2015 lord63"


from encode import *
from decode import *


